summaryrefslogtreecommitdiffstats
path: root/net/proxy/proxy_script_fetcher_impl.cc
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-01-15 00:21:34 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-01-15 00:21:34 +0000
commitaeb53f0e2f6352ec7fbc2113270a97072b42c764 (patch)
tree1f4da7884df919c21903a7881964273a9f7496fd /net/proxy/proxy_script_fetcher_impl.cc
parentec8962ca7de01eb5685b32a4361dd7be8f7e6293 (diff)
downloadchromium_src-aeb53f0e2f6352ec7fbc2113270a97072b42c764.zip
chromium_src-aeb53f0e2f6352ec7fbc2113270a97072b42c764.tar.gz
chromium_src-aeb53f0e2f6352ec7fbc2113270a97072b42c764.tar.bz2
net: Remove typedef net::URLRequestContext URLRequestContext;
BUG=64263 TEST=compiled locally, trybots Review URL: http://codereview.chromium.org/6338002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@71522 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/proxy/proxy_script_fetcher_impl.cc')
-rw-r--r--net/proxy/proxy_script_fetcher_impl.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/net/proxy/proxy_script_fetcher_impl.cc b/net/proxy/proxy_script_fetcher_impl.cc
index 0a54046..0724127 100644
--- a/net/proxy/proxy_script_fetcher_impl.cc
+++ b/net/proxy/proxy_script_fetcher_impl.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -70,7 +70,7 @@ void ConvertResponseToUTF16(const std::string& charset,
} // namespace
ProxyScriptFetcherImpl::ProxyScriptFetcherImpl(
- URLRequestContext* url_request_context)
+ net::URLRequestContext* url_request_context)
: ALLOW_THIS_IN_INITIALIZER_LIST(task_factory_(this)),
url_request_context_(url_request_context),
buf_(new net::IOBuffer(kBufSize)),
@@ -134,7 +134,7 @@ void ProxyScriptFetcherImpl::Cancel() {
ResetCurRequestState();
}
-URLRequestContext* ProxyScriptFetcherImpl::GetRequestContext() {
+net::URLRequestContext* ProxyScriptFetcherImpl::GetRequestContext() {
return url_request_context_;
}
@@ -260,9 +260,9 @@ void ProxyScriptFetcherImpl::FetchCompleted() {
int result_code = result_code_;
CompletionCallback* callback = callback_;
- // Hold a reference to the URLRequestContext to prevent re-entrancy from
- // ~URLRequestContext.
- scoped_refptr<URLRequestContext> context(cur_request_->context());
+ // Hold a reference to the net::URLRequestContext to prevent re-entrancy from
+ // ~net::URLRequestContext.
+ scoped_refptr<net::URLRequestContext> context(cur_request_->context());
ResetCurRequestState();
callback->Run(result_code);